/****************************************************************************
 *   Copyright (C) 2004 by Jurij Ivastsuk-Kienbaum                      *
 *   jurij.ivastsuk@t-online.de                                             *
 *                                                                          *
 *   This program is free software; you can redistribute it and/or modify   *
 *   it under the terms of the GNU General Public License as published by   *
 *   the Free Software Foundation; either version 2 of the License,         *
 *   or (at your option) any later version.                                 *
 *   This program is distributed in the hope that it will be useful,        *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty            *
 *   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                *
 *   See the GNU General Public License for more details.                   *
 *   You should have received a copy of the GNU General Public License      *
 *   along with this program; if not, write to the Free Software Foundation,*
 *   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA            *
 ***************************************************************************/
#include <unistd.h>
#include "safe_write.h"
#include <errno.h>
#include "zlib.h"
#ifndef errno
extern int errno;
#endif


 /* Write(read) COUNT bytes at BUF to(from) descriptor FD, retrying if
   interrupted or if a partial write(read) occurs.  Return the number
   of bytes transferred.
   When writing, set errno if fewer than COUNT bytes are written.
   When reading, if fewer than COUNT bytes are read, you must examine
   errno to distinguish failure from EOF (errno == 0).  */

size_t safe_write(int fd, Bytef *buf, size_t count)
{
  size_t total = 0;
  size_t n_rw;
  Bytef *ptr = buf;

  while (count > 0)
    {
      n_rw = write(fd, ptr, count);
      if (n_rw == -1)
	break;
      if (n_rw == 0)
	{
	  errno = 0;
	  break;
	}
      total += n_rw;
      ptr += n_rw;
      count -= n_rw;
    }

  return total;
}
